@@ -37,7 +37,8 @@
 #include "types.h"
 #include "utils.h"
 #include "feedretriever.h"
-
+#include "job/downloadfeediconjob.h"
+#include <syndication_version.h>
 #include <Syndication/Syndication>
 
 #include "akregator_debug.h"
@@ -101,6 +102,7 @@ public:
     QString m_htmlUrl;
     QString m_description;
     QString m_comment;
+    QString m_faviconUrl;
 
     /** list of feed articles */
     QHash<QString, Article> articles;
@@ -165,10 +167,12 @@ Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
     const bool useNotification = e.attribute(QStringLiteral("useNotification")) == QLatin1String("true");
     const bool loadLinkedWebsite = e.attribute(QStringLiteral("loadLinkedWebsite")) == QLatin1String("true");
     const QString comment = e.attribute(QStringLiteral("comment"));
+    const QString faviconUrl = e.attribute(QStringLiteral("faviconUrl"));
     const uint id = e.attribute(QStringLiteral("id")).toUInt();
 
     Feed *const feed = new Feed(storage);
     feed->setTitle(title);
+    feed->setFaviconUrl(faviconUrl);
     feed->setXmlUrl(xmlUrl);
     feed->setCustomFetchIntervalEnabled(useCustomFetchInterval);
     feed->setHtmlUrl(htmlUrl);
@@ -340,14 +344,17 @@ Feed::~Feed()
     d = nullptr;
 }
 
-void Feed::loadFavicon(const QUrl &url)
+void Feed::loadFavicon(const QString &url, bool downloadFavicon)
 {
-    KIO::FavIconRequestJob *job = new KIO::FavIconRequestJob(url);
-    connect(job, &KIO::FavIconRequestJob::result, this, [job, this](KJob *) {
-        if (!job->error()) {
-            setFavicon(QIcon(job->iconFile()));
-        }
+    Akregator::DownloadFeedIconJob *job = new Akregator::DownloadFeedIconJob(this);
+    job->setFeedIconUrl(url);
+    job->setDownloadFavicon(downloadFavicon);
+    connect(job, &DownloadFeedIconJob::result, this, [job, this](const QString &result) {
+        setFaviconUrl(result);
     });
+    if (!job->start()) {
+        qCWarning(AKREGATOR_LOG) << "Impossible to start DownloadFeedIconJob for url: " << url;
+    }
 }
 
 bool Feed::useCustomFetchInterval() const
@@ -463,6 +470,17 @@ void Feed::setHtmlUrl(const QString &s)
     d->m_htmlUrl = s;
 }
 
+QString Feed::faviconUrl() const
+{
+    return d->m_faviconUrl;
+}
+
+void Feed::setFaviconUrl(const QString &url)
+{
+    d->m_faviconUrl = url;
+    setFavicon(QIcon(url));
+}
+
 QString Feed::description() const
 {
     return d->m_description;
@@ -512,6 +530,7 @@ QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
     if (d->m_loadLinkedWebsite) {
         el.setAttribute(QStringLiteral("loadLinkedWebsite"), QStringLiteral("true"));
     }
+    el.setAttribute(QStringLiteral("faviconUrl"), d->m_faviconUrl);
     el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
     el.setAttribute(QStringLiteral("type"), QStringLiteral("rss"));   // despite some additional fields, it is still "rss" OPML
     el.setAttribute(QStringLiteral("version"), QStringLiteral("RSS"));
@@ -543,9 +562,9 @@ void Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
             interval = Settings::autoFetchInterval() * 60;
         }
 
-        uint lastFetch = d->m_archive->lastFetch().toTime_t();
+        uint lastFetch = d->m_archive->lastFetch().toSecsSinceEpoch();
 
-        uint now = QDateTime::currentDateTimeUtc().toTime_t();
+        uint now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
 
         if (interval > 0 && (now - lastFetch) >= static_cast<uint>(interval)) {
             queue->addFeed(this);
@@ -555,7 +574,11 @@ void Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
 
 void Feed::slotAddFeedIconListener()
 {
-    loadFavicon(QUrl(d->m_xmlUrl));
+    if (d->m_faviconUrl.isEmpty()) {
+        loadFavicon(d->m_xmlUrl, true);
+    } else {
+        loadFavicon(d->m_faviconUrl, false);
+    }
 }
 
 void Feed::appendArticles(const Syndication::FeedPtr &feed)
@@ -727,8 +750,15 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
 
     loadArticles(); // TODO: make me fly: make this delayed
 
-    loadFavicon(QUrl(xmlUrl()));
-
+#if SYNDICATION_VERSION >= QT_VERSION_CHECK(5,65,0)
+    if (!doc->icon().isNull() && !doc->icon()->url().isEmpty()) {
+        loadFavicon(doc->icon()->url(), false);
+    } else {
+        loadFavicon(xmlUrl(), true);
+    }
+#else
+    loadFavicon(xmlUrl(), true);
+#endif
     d->m_fetchErrorCode = Syndication::Success;
 
     if (d->m_imagePixmap.isNull()) {
