@@ -155,6 +155,9 @@ public:
     /** sets the URL of the HTML page of this feed */
     void setHtmlUrl(const QString &s);
 
+    Q_REQUIRED_RESULT QString faviconUrl() const;
+    void setFaviconUrl(const QString &url);
+
     /** returns the description of this feed */
     QString description() const;
 
@@ -247,7 +250,7 @@ private:
 
 private:
     void setFavicon(const QIcon &icon);
-    void loadFavicon(const QUrl &url);
+    void loadFavicon(const QString &url, bool downloadFavicon);
     QVector<Article> articles() override;
 
     /** loads articles from archive **/
