@@ -21,6 +21,7 @@
 #include "articlegrantleeobject.h"
 #include "utils.h"
 #include "akregatorconfig.h"
+#include "grantleeutil.h"
 #include <KLocalizedString>
 
 #include <grantlee/engine.h>
@@ -41,6 +42,7 @@ GrantleeViewFormatter::GrantleeViewFormatter(const QString &htmlFileName, const
     , mDeviceDpiY(deviceDpiY)
 {
     mDirectionString = QApplication::isRightToLeft() ? QStringLiteral("rtl") : QStringLiteral("ltr");
+    setApplicationDomain("akregator");
 }
 
 GrantleeViewFormatter::~GrantleeViewFormatter()
@@ -80,11 +82,7 @@ QString GrantleeViewFormatter::formatFeed(Akregator::Feed *feed)
 
     QString feedImage;
     if (!feed->image().isNull()) { // image
-        QString file = Utils::fileNameForUrl(feed->xmlUrl());
-        QUrl u(mImageDir);
-        u = u.adjusted(QUrl::RemoveFilename);
-        u.setPath(u.path() + file);
-        feedImage = QStringLiteral("<a href=\"%1\"><img class=\"headimage\" src=\"%2.png\"></a>\n").arg(feed->htmlUrl(), u.url());
+        feedImage = GrantleeUtil::imageFeed(feed, mImageDir);
     } else {
         feedImage = QStringLiteral("<div class=\"body\">");
     }
@@ -101,7 +99,7 @@ QString GrantleeViewFormatter::formatFeed(Akregator::Feed *feed)
     if (!feed->htmlUrl().isEmpty()) {
         QString feedHomePage;
         feedHomePage = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
-        feedHomePage += i18n("<b>Homepage:</b> <a href=\"%1\">%2</a>", feed->htmlUrl(), feed->htmlUrl());
+        feedHomePage += i18n("<b>Homepage:</b> <a href=\"%1\">%1</a>", feed->htmlUrl());
         feedHomePage += QStringLiteral("</div>"); // / link
         feedObject.insert(QStringLiteral("feedHomePage"), feedHomePage);
     }
